@@ -6,7 +6,7 @@ use warnings;
 use List::MoreUtils qw/any none/;
 use Carp;
 
-my $SKIPPATTERN = qr{^(?:collection|hyphen)-};
+my $SKIPPATTERN = qr{^(?:collection)-};
 
 
 # TeXLive collections in the texlive-core package:
@@ -16,60 +16,25 @@ my @core_colls = qw/
   context
   fontsrecommended
   genericrecommended
+  langcjk
   langczechslovak
-  langdutch
+  langenglish
+  langeuropean
   langfrench
   langgerman
   langitalian
   langpolish
   langportuguese
   langspanish
-  langenglish
   latex
   latexrecommended
   luatex
-  mathextra
   metapost
-  texinfo
   xetex
   /;
 
-## other collections in CORE or BIN:
-# langdanish langfinnish langlatin langhungarian langlatvian langlithuanian
-# langnorwegian langother langswedish
-
-# only the following two contain packages that are not already contained in
-# texlive-bin:
-push @core_colls, qw/ langhungarian langlithuanian /;
-
-# also langswedish and langfinnish contain swebib and finbib, resp.,
-# which we add later to bibtexextra
-
 # collections that are specific to texlive-core-doc:
 my @core_doc_colls = qw(
-    documentation-base
-    documentation-arabic
-    documentation-bulgarian
-    documentation-chinese
-    documentation-czechslovak
-    documentation-dutch
-    documentation-english
-    documentation-finnish
-    documentation-french
-    documentation-german
-    documentation-italian
-    documentation-japanese
-    documentation-korean
-    documentation-mongolian
-    documentation-polish
-    documentation-portuguese
-    documentation-russian
-    documentation-slovenian
-    documentation-spanish
-    documentation-thai
-    documentation-turkish
-    documentation-ukrainian
-    documentation-vietnamese
 );
 
 # These are the other collections that define Arch Linux packages:
@@ -81,9 +46,11 @@ my @other_colls = qw(
     genericextra
     htmlxml
     humanities
-    langcjk
+    langchinese
     langcyrillic
     langgreek
+    langjapanese
+    langkorean
     latexextra
     music
     pictures
@@ -98,23 +65,11 @@ my @other_colls = qw(
 my @langextra_colls = qw(
     langafrican
     langarabic
-    langarmenian
-    langcroatian
-    langhebrew
     langindic
-    langmongolian
-    langtibetan
-    langturkmen
-    langvietnamese
+    langother
 );
 
-# we add swebib and finbib to bibtexextra:
-my @bibtexadd = qw( swebib finbib );
-
-# but only swebib has documentation:
-my @bibtexdocadd = qw( swebib );
-
-my @core_additional = qw( bidi iftex pgf ruhyphen ukrhyph );
+my @core_additional = qw( bidi iftex pgf );
 my @coredoc_additional = qw( bidi iftex pgf luatex pdftex );
 
 sub collection_with_runfiles_pattern {
@@ -160,8 +115,6 @@ sub archpackages {
     push @{ $tlpackages{'core-doc'} }, @coredoc_additional;
     push @{ $tlpackages{'core-doc'} },
         $self->collection_with_docfiles_pattern('binextra', 'texmf-dist|RELOC');
-    push @{ $tlpackages{'bibtexextra'} },     @bibtexadd;
-    push @{ $tlpackages{'bibtexextra-doc'} }, @bibtexdocadd;
 
     # We now produce the list of upstream packages that we put in
     # texlive-core:
@@ -202,34 +155,30 @@ sub archpackages {
         }
     }
 
-    my $tlpcoll_fontsextra = $self->get_package("collection-fontsextra")
-        or croak "Can't get object for collection-fontsextra" ;
-    foreach my $d ( $tlpcoll_fontsextra->depends ) {
-        next if $d =~ /^(aleph|ocherokee|oinuit)$/;
-        push @{ $tlpackages{'fontsextra'} }, $d
-        unless $d =~ /$SKIPPATTERN/;
-        my $tlpdep = $self->get_package($d);
-        if ( ( $tlpdep->doccontainermd5 or $tlpdep->docsize )
-            and $d !~ /$SKIPPATTERN/ )
-        {
-            push @{ $tlpackages{'fontsextra-doc'} }, $d;
-        }
-    }
-
     foreach my $coll (@other_colls) {
-        next if $coll eq 'fontsextra';
-        my $tlpcoll = $self->get_package("collection-$coll")
-            or croak "Can't get object for collection-$coll";
+        my $tlpcoll;
+        if ($coll eq "science") {
+            $tlpcoll = $self->get_package("collection-mathscience")
+                or croak "Can't get object for collection-mathscience";
+        } else {
+            $tlpcoll = $self->get_package("collection-$coll")
+                or croak "Can't get object for collection-$coll";
+        }
         foreach my $d ( $tlpcoll->depends ) {
+            my $tlpdep = $self->get_package($d);
+            next if ( $coll =~ /^fontsextra/ and $d =~ /^(aleph|ocherokee|oinuit)$/ );
             next if ( $coll =~ /^pictures/ and $d eq 'pgf' );
             next if ( $coll =~ /^genericextra/ and $d eq 'iftex' );
-            next if (
-                $coll =~ /^langcyrillic/
-                and ( $d eq 'ruhyphen' or $d eq 'ukrhyph' )
-            );
+            if ( $d eq 'ruhyphen' or $d eq 'ukrhyph' or
+                 $d =~ /^hyphen-/ ) {
+                 # Hyphen packages go to core.
+                 push @{ $tlpackages{'core'} }, $d;
+                 push @{ $tlpackages{"core-doc"} }, $d
+                 if ( $tlpdep->doccontainermd5 or $tlpdep->docsize );
+                 next;
+            }
             push @{ $tlpackages{$coll} }, $d
             unless $d =~ /$SKIPPATTERN/;
-            my $tlpdep = $self->get_package($d);
             if (
                 ( $tlpdep->doccontainermd5
                     or $tlpdep->docsize )
@@ -241,14 +190,22 @@ sub archpackages {
         }
     }
 
+    # Build texlive-langextra
     foreach my $coll (@langextra_colls) {
         my $tlpcoll = $self->get_package("collection-$coll")
             or croak "Can't get object for collection-$coll";
         foreach my $d ( $tlpcoll->depends ) {
-            next if $d =~ /^(omega-devanagari|otibet|bidi)$/;
-            push @{ $tlpackages{'langextra'} }, $d
-            unless ( $d eq 'ebong' or $d =~ /$SKIPPATTERN/ );
+            next if ( $d =~ /^(bidi|ebong)$/ ); # bidi is in core
             my $tlpdep = $self->get_package($d);
+            if ( $d =~ /^hyphen-/ ) {
+                 # Hyphen packages go to core.
+                 push @{ $tlpackages{'core'} }, $d;
+                 push @{ $tlpackages{"core-doc"} }, $d
+                 if ( $tlpdep->doccontainermd5 or $tlpdep->docsize );
+                 next;
+            }
+            push @{ $tlpackages{'langextra'} }, $d
+            unless $d =~ /$SKIPPATTERN/;
             if (
                 ( $tlpdep->doccontainermd5
                     or $tlpdep->docsize )
@@ -270,6 +227,8 @@ sub archversions {
 
     foreach my $coll ( keys %tlpackages ) {
         my @tmp;
+        my $tlpkg = $self->get_package("collection-$coll");
+        push @tmp, $tlpkg->revision if $tlpkg;
         foreach my $pkg ( @{ $tlpackages{$coll} } ) {
             my $tlpkg = $self->get_package($pkg) or croak "Can't get package $pkg: $!";
             #say "Looking for revision nr of package $pkg for $coll";
